@@ -60,7 +60,7 @@ class this:
 
     rich_code_themes = ["monokai", "paraiso-dark", "igor", "vs", "fruity", "xcode"]
 
-    default_provider = "phind"
+    default_provider = "auto"
 
     getExc = lambda e: e.args[1] if len(e.args) > 1 else str(e)
 
@@ -382,13 +382,28 @@ class Main(cmd.Cmd):
                 intro = self.RawDog.intro_prompt
                 getpass.getuser = lambda: "RawDog"
 
-            if provider == "g4fauto":
+            if provider == "auto":
+                from pytgpt.auto import AUTO
+
+                self.bot = AUTO(
+                    is_conversation=disable_conversation,
+                    max_tokens=max_tokens,
+                    timeout=timeout,
+                    intro=intro,
+                    filepath=filepath,
+                    update_file=update_file,
+                    proxies=proxies,
+                    history_offset=history_offset,
+                    act=awesome_prompt,
+                )
+
+            elif provider == "g4fauto":
                 from pytgpt.gpt4free.utils import TestProviders
 
                 test = TestProviders(quiet=quiet, timeout=timeout)
                 g4fauto = test.best if ignore_working else test.auto
                 if isinstance(g4fauto, str):
-                    provider = "g4fauto+" + g4fauto
+                    provider = "g4f-" + g4fauto
                     from pytgpt.gpt4free import GPT4FREE
 
                     self.bot = GPT4FREE(
@@ -710,6 +725,13 @@ class Main(cmd.Cmd):
         self.__start_time = time.time()
         self.__end_time = time.time()
 
+    @property
+    def get_provider(self):
+        if self.provider == "auto" and self.bot.provider_name is not None:
+            return self.bot.provider_name
+        else:
+            return self.provider
+
     @property
     def prompt(self):
         current_time = datetime.datetime.now().strftime("%H:%M:%S")
@@ -725,7 +747,7 @@ class Main(cmd.Cmd):
         if not self.disable_coloring:
             cmd_prompt = (
                 f"╭─[`{Fore.CYAN}{getpass.getuser().capitalize()}@pyTGPT]`"
-                f"(`{Fore.MAGENTA}{self.provider})`"
+                f"(`{Fore.MAGENTA}{self.get_provider})`"
                 f"~[`{Fore.LIGHTWHITE_EX}🕒{Fore.BLUE}{current_time}-`"
                 f"{Fore.LIGHTWHITE_EX}💻{Fore.RED}{find_range(self.__init_time, time.time(), True)}-`"
                 f"{Fore.LIGHTWHITE_EX}⚡{Fore.YELLOW}{find_range(self.__start_time, self.__end_time)}s]`"
@@ -738,7 +760,7 @@ class Main(cmd.Cmd):
 
         else:
             return (
-                f"╭─[{getpass.getuser().capitalize()}@pyTGPT]({self.provider})"
+                f"╭─[{getpass.getuser().capitalize()}@pyTGPT]({self.get_provider})"
                 f"~[🕒{current_time}"
                 f"-💻{find_range(self.__init_time, time.time(), True)}"
                 f"-⚡{find_range(self.__start_time, self.__end_time)}s]"
